import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'
export const constantRoutes = [{
        // 用户登录路由
        path: '/login',
        component: () =>
            import ('@/views/login/index.vue'),
        hidden: true
    },
    {
        // 用户注册路由
        path: '/register',
        name: 'register',
        component: () =>
            import ('@/views/register/index.vue'),
        hidden: true
    },

    {
        // 404路由
        path: '/404',
        component: () =>
            import ('@/views/404'),
        hidden: true
    },

    {
        path: '/',
        component: Layout,
        redirect: '/parking/parkingList',
        meta: { title: '首页', icon: 'dashboard' },
        children: [{
            path: 'dashboard',
            name: 'Dashboard',
            component: () =>
                import ('@/views/dashboard/index'),
            meta: { title: '控制台', icon: 'dashboard' },
            children: [{
                path: 'cars',
                name: 'Car',
                component: () =>
                    import ('@/views/Car/Car.vue'),
                meta: { title: '停车场大图', icon: 'car' }
            }]
        }]
    },
    // 停车场
    {
        path: '/parking',
        component: Layout,
        redirect: '/parking/parkingList',
        name: 'Parking',
        meta: { title: '营业网店', icon: 'parking' },

        children: [{
            path: 'parkingList',
            name: 'ParkingList',
            component: () =>
                import ('@/views/parking/parkingList'),
            meta: { title: '网点列表' }
        }]
    },
    // 车辆品牌
    {
        path: '/carBrand',
        component: Layout,
        redirect: '/carBrand/brandList',
        name: 'CarBrand',
        meta: { title: '车辆品牌', icon: 'pinpaizhuanqu' },
        alwaysShow: true,
        children: [{
            path: 'brandList',
            name: 'BrandList',
            component: () =>
                import ('@/views/carBrand/brandList'),
            meta: { title: '品牌列表' }
        }]
    },
    // 车辆管理
    {
        path: '/carManage',
        component: Layout,
        redirect: '/carManage/carList',
        name: 'CarManage',
        meta: { title: '订单管理', icon: 'cheliangguanli' },
        alwaysShow: true,
        children: [{
            path: 'carList',
            name: 'CarList',
            component: () =>
                import ('@/views/carManage/carList'),
            meta: { title: '订单列表' }
        }]
    },
    // 会员管理
    {
        path: '/memberManage',
        component: Layout,
        redirect: '/memberManage/memberList',
        name: 'MemberManage',
        meta: { title: '个人中心', icon: 'member' },
        alwaysShow: true,
        children: [{
            path: 'memberList',
            name: 'MemberList',
            component: () =>
                import ('@/views/memberManage/memberList'),
            meta: { title: '我的资料' }
        }]
    },

    // 404 page must be placed at the end !!!
    { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
    const newRouter = createRouter()
    router.matcher = newRouter.matcher // reset router
}

export default router